@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 package EBox::Migration;
-use base 'EBox::MigrationBase';
+use base 'EBox::Migration::Base';
 
 use strict;
 use warnings;
@@ -23,7 +23,7 @@ use Error qw(:try);
 
 # Method: runGConf
 #
-#   Overrides <EBox::MigrationBase::runGConf>
+#   Overrides <EBox::Migration::Base::runGConf>
 #
 sub runGConf
 {
