@@ -58,7 +58,7 @@ use constant SMBLDAPTOOLBINDFILE_GID => '0';
 use constant SMBLDAPTOOLCONFFILE  => '/etc/smbldap-tools/smbldap.conf';
 use constant SMBPIDFILE           => '/var/run/samba/smbd.pid';
 use constant NMBPIDFILE           => '/var/run/samba/nmbd.pid';
-use constant MAXNETBIOSLENGTH     => 32;
+use constant MAXNETBIOSLENGTH     => 15;
 use constant MAXWORKGROUPLENGTH   => 32;
 use constant MAXDESCRIPTIONLENGTH => 255;
 use constant SMBPORTS => qw(137 138 139 445);
@@ -73,18 +73,13 @@ sub _create
 {
     my $class = shift;
     my $self = $class->SUPER::_create(name => 'samba',
-            printableName => __('File Sharing'),
+            printableName => __n('File Sharing'),
             domain => 'ebox-samba',
             @_);
     bless($self, $class);
     return $self;
 }
 
-sub domain
-{
-    return 'ebox-samba';
-}
-
 # Method: actions
 #
 #	Override EBox::Module::Service::actions
@@ -157,7 +152,7 @@ sub usedFiles
         'file' => '/etc/samba/vscan-clamav.conf',
         'reason' => __('To set the antivirus settings for Samba'),
         'module' => 'samba'
-    }
+    },
     ];
 }
 
@@ -195,6 +190,9 @@ sub modelClasses
                'EBox::Samba::Model::DeletedSambaShares',
                'EBox::Samba::Model::AntivirusDefault',
                'EBox::Samba::Model::AntivirusExceptions',
+               'EBox::Samba::Model::RecycleDefault',
+               'EBox::Samba::Model::RecycleExceptions',
+               'EBox::Samba::Model::SambaUser',
            ];
 
 }
@@ -213,6 +211,7 @@ sub compositeClasses
     return [
              'EBox::Samba::Composite::General',
              'EBox::Samba::Composite::Antivirus',
+             'EBox::Samba::Composite::RecycleBin',
            ];
 }
 
@@ -321,6 +320,54 @@ sub antivirusExceptions
     return $exceptions;
 }
 
+sub defaultRecycleSettings
+{
+    my ($self) = @_;
+    my $recycle = $self->model('RecycleDefault');
+    return $recycle->row()->valueByName('enabled');
+}
+
+sub recycleExceptions
+{
+    my ($self) = @_;
+    my $model = $self->model('RecycleExceptions');
+    my $exceptions = {
+        'share' => {},
+        'group' => {},
+    };
+
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
+        my $element = $row->elementByName('user_group_share');
+        my $type = $element->selectedType();
+        if ($type eq 'users') {
+            $exceptions->{'users'} = 1;
+        } else {
+            my $value = $element->printableValue();
+            $exceptions->{$type}->{$value} = 1;
+        }
+    }
+    return $exceptions;
+}
+
+sub recycleConfig
+{
+    my ($self) = @_;
+
+    my $conf = {};
+    my @keys = ('repository', 'directory_mode', 'keeptree', 'versions',
+                'maxsize', 'exclude', 'excludedir', 'noversions');
+
+    foreach my $key (@keys) {
+        my $value = EBox::Config::configkey($key);
+        if ($value) {
+            $conf->{$key} = $value;
+        }
+    }
+
+    return $conf;
+}
+
 sub _exposedMethods
 {
     return {
@@ -424,7 +471,6 @@ sub _setConf
     push(@array, 'dirgroup'  => $smbimpl->groupShareDirectories);
     push(@array, 'ifaces'    => $interfaces);
     push(@array, 'printers'  => $self->_sambaPrinterConf());
-    push(@array, 'active_file' => $self->fileService());
     push(@array, 'active_printer' => $self->printerService());
     push(@array, 'pdc' => $self->pdc());
     push(@array, 'roaming' => $self->roamingProfiles());
@@ -433,6 +479,10 @@ sub _setConf
     push(@array, 'shares' => $self->shares());
     push(@array, 'antivirus' => $self->defaultAntivirusSettings());
     push(@array, 'antivirus_exceptions' => $self->antivirusExceptions());
+    push(@array, 'recycle' => $self->defaultRecycleSettings());
+    push(@array, 'recycle_exceptions' => $self->recycleExceptions());
+    push(@array, 'recycle_config' => $self->recycleConfig());
+
 
     $self->writeConfFile(SMBCONFFILE, "samba/smb.conf.mas", \@array);
 
@@ -673,43 +723,10 @@ sub menu
 
     $root->add(new EBox::Menu::Item('url' => 'Samba/Composite/General',
                                     'text' => $self->printableName(),
-                                    'separator' => __('Office'),
+                                    'separator' => 'Office',
                                     'order' => 540));
 }
 
-#   Function: setFileService
-#
-#       Sets the file sharing service through samba
-#
-#   Parameters:
-#
-#       enabled - boolean. True enable, undef disable
-#
-sub setFileService # (enabled)
-{
-    my ($self, $active) = @_;
-    ($active and $self->fileService) and return;
-    (!$active and !$self->fileService) and return;
-
-    $self->enableService($active);
-}
-
-#   Function: fileService
-#
-#       Returns if the file sharing service is enabled
-#
-#   Returns:
-#
-#       boolean - true if enabled, otherwise undef
-#
-sub fileService
-{
-    my ($self) = @_;
-
-    return $self->isEnabled();
-}
-
-
 #   Function: setPrinterService
 #
 #       Sets the printer sharing service through samba and cups
@@ -1312,30 +1329,11 @@ sub setUserQuota
     root(QUOTA_PROGRAM . " -s $user $quota");
 }
 
-sub extendedBackup
-{
-    my ($self, %options) = @_;
-    my $dir     = $options{dir};
-
-    $self->_dumpProfiles($dir);
-    $self->_dumpSharesFiles($dir);
-}
-
-sub extendedRestore
-{
-    my ($self, %options) = @_;
-    my $dir     = $options{dir};
-
-    $self->_loadProfiles($dir);
-    $self->_loadSharesFiles($dir);
-}
-
 sub dumpConfig
 {
     my ($self, $dir) = @_;
 
     $self->_dumpSharesTree($dir);
-
 }
 
 sub restoreConfig
@@ -1412,38 +1410,6 @@ sub _loadSharesTree
     }
 }
 
-
-sub _dumpProfiles
-{
-    my ($self, $dir) = @_;
-    my $archive = $self->_profilesArchive($dir);
-
-    (-d PROFILESPATH) or return;
-
-    my $tarCommand = "/bin/tar -cf $archive --bzip2 --atime-preserve --absolute-names --preserve --same-owner " . PROFILESPATH;
-    EBox::Sudo::root($tarCommand);
-}
-
-
-sub _loadProfiles
-{
-    my ($self, $dir) = @_;
-    my $archive = $self->_profilesArchive($dir);
-
-    (-e $archive) or
-        return;
-
-    my $tarCommand = "/bin/tar -xf $archive --bzip2 --atime-preserve --absolute-names --preserve --same-owner";
-    EBox::Sudo::root($tarCommand);
-}
-
-
-sub _profilesArchive
-{
-    my ($self, $dir) = @_;
-    return "$dir/profiles.tgz";
-}
-
 sub fixSIDs
 {
     my ($self)  = @_;
@@ -1526,56 +1492,6 @@ sub _sharesTreeFile
     return "$dir/sharesTree.bak";
 }
 
-sub  _dumpSharesFiles
-{
-    my ($self, $dir) = @_;
-
-    my $sambaLdapUser = new EBox::SambaLdapUser;
-    my @dirs;
-    foreach my $share (@{ $sambaLdapUser->sharedDirectories()}) {
-        next if grep { EBox::FileSystem::isSubdir($share, $_) } @dirs; # ignore if is a subdir of a directory already in the list
-            @dirs = grep { !EBox::FileSystem::isSubdir($_, $share)  } @dirs; # remove subdirectories of share from the list
-            push @dirs, $share;
-    }
-
-    # escape directories
-    @dirs = map {  "'$_'" } @dirs;
-
-    if (@dirs > 0) {
-        my $tarFile = $self->_sharesFilesArchive($dir);
-
-        my $tarCommand = "/bin/tar -cf $tarFile --bzip2 --atime-preserve --absolute-names --preserve --same-owner @dirs";
-        EBox::Sudo::root($tarCommand);
-    }
-
-
-}
-
-
-sub  _loadSharesFiles
-{
-    my ($self, $restoreDir) = @_;
-
-    my $tarFile = $self->_sharesFilesArchive($restoreDir);
-
-    if (-e $tarFile) {
-        my $tarCommand = "/bin/tar -xf $tarFile --bzip2 --atime-preserve --absolute-names --preserve --same-owner";
-        EBox::Sudo::root($tarCommand);
-    }
-    else {
-        EBox::error("Share's files archive not found at $tarFile. Share's files will NOT be restored.\n Resuming restoring process..")
-    }
-
-
-}
-
-
-sub  _sharesFilesArchive
-{
-    my ($self, $dir) = @_;
-    my $archive = "$dir/shares.tar.bz2";
-    return $archive;
-}
 
 
 # we look for shared directories leftover from users and groups created
@@ -1825,4 +1741,48 @@ sub isAntivirusPresent
              and (-f '/usr/lib/samba/vfs/vscan-clamav.so'));
 }
 
+sub report
+{
+    my ($self, $beg, $end, $options) = @_;
+
+    my $report = {};
+
+    $report->{'activity'} = $self->runMonthlyQuery($beg, $end, {
+        'select' => 'COALLESCE(SUM(operations) AS operations, 0)',
+        'from' => 'samba_access_report'
+    });
+
+    $report->{'top_activity_users'} = $self->runQuery($beg, $end, {
+        'select' => 'username, SUM(operations) AS operations',
+        'from' => 'samba_access_report',
+        'group' => 'username',
+        'limit' => $options->{'max_top_activity_users'},
+        'order' => 'operations DESC'
+    });
+
+    return $report;
+}
+
+sub consolidateReportQueries
+{
+    return [
+        {
+            'target_table' => 'samba_access_report',
+            'query' => {
+                'select' => 'username, COUNT(event) AS operations',
+                'from' => 'samba_access',
+                'group' => 'username'
+            }
+        },
+        {
+            'target_table' => 'samba_virus_report',
+            'query' => {
+                'select' => 'client, COUNT(event) AS virus',
+                'from' => 'samba_virus',
+                'group' => 'client'
+            }
+        },
+    ];
+}
+
 1;
