@@ -20,11 +20,13 @@ use warnings;
 
 use EBox::Sudo qw( :all );
 use EBox::Global;
+use EBox::Model::ModelManager;
 use EBox::Network;
 use EBox::Exceptions::InvalidData;
 use EBox::Exceptions::Internal;
 use EBox::Exceptions::DataExists;
 use EBox::Exceptions::DataMissing;
+
 use EBox::Gettext;
 
 use Perl6::Junction qw(any all);
@@ -41,6 +43,7 @@ use constant SMBPWDCANCHANGE    => '0';
 use constant SMBPWDMUSTCHANGE   => '2147483647';
 use constant SMBGROUP           => '513';
 use constant SMBACCTFLAGS       => '[U]';
+use constant SMBACCTFLAGSDISABLED       => '[UD]';
 use constant GECOS              => 'Ebox file sharing user ';
 use constant USERGROUP          => 513;
 use constant DEFAULT_SHELL      => '/bin/false';
@@ -110,6 +113,16 @@ sub _domainUser
 sub _userCommonLdapAttrs
 {
     my ($self) = @_;
+
+    my $defaultFlags;
+    my $model =
+        EBox::Model::ModelManager::instance()->model('samba/SambaUser');
+    if ($model->enabledValue()) {
+        $defaultFlags = SMBACCTFLAGS;
+    } else {
+        $defaultFlags = SMBACCTFLAGSDISABLED;
+    }
+
     my $attrs = {
         sambaLogonTime       => SMBLOGONTIME,
         sambaLogoffTime      => SMBLOGOFFTIME,
@@ -120,7 +133,7 @@ sub _userCommonLdapAttrs
         sambaPasswordHistory => '0' x56,
         sambaPwdLastSet      => time(),
 
-        sambaAcctFlags       => SMBACCTFLAGS,
+        sambaAcctFlags       => $defaultFlags,
 
         loginShell            => _loginShell(),
     };
@@ -226,6 +239,7 @@ sub _addUser
     my  $samba = EBox::Global->modInstance('samba');
     $self->_createDir(USERSPATH . "/$user", $unixuid, USERGROUP, '0701');
     $self->_createDir(PROFILESPATH . "/$user", $unixuid, USERGROUP, '0700');
+    $self->_createDir(PROFILESPATH . "/$user.V2", $unixuid, USERGROUP, '0700');
     $self->{samba}->setUserQuota($unixuid, $samba->defaultUserQuota());
 }
 
@@ -269,6 +283,9 @@ sub _delUser($$)
     if ( -d BASEPATH . "/profiles/$user") {
         root ("rm -rf \'" .  BASEPATH . "/profiles/$user\'");
     }
+    if ( -d BASEPATH . "/profiles/$user.V2") {
+        root ("rm -rf \'" .  BASEPATH . "/profiles/$user.V2\'");
+    }
 
     # Remove user from printers
     my $samba = EBox::Global->modInstance('samba');
@@ -297,7 +314,6 @@ sub _delUserWarning
 sub _addGroup
 {
     my ($self, $group) = @_;
-
     return unless ($self->{samba}->configured());
 
     $self->addGroupLdapAttrs($group);
@@ -313,8 +329,10 @@ sub addGroupLdapAttrs
 
     my $ldap  = $self->{ldap};
     my $users = EBox::Global->modInstance('users');
+    my $groupInfo = $users->groupInfo($group);
+    my $unixgid = $groupInfo->{gid};
 
-    my $rid = 2 * $users->lastGid + 1001;
+    my $rid = 2 * $unixgid + 1001;
 
     if (not defined $sambaSID) {
         my $baseSid = alwaysGetSID();
@@ -365,7 +383,7 @@ sub setGroupSID
     my ($self, $group, $sid) = @_;
 
     checkSID($sid) or
-    throw EBox::Exceptions::External(__('Incoorect SID: {s}', 's' => $sid));
+    throw EBox::Exceptions::External(__('Incorrect SID: {s}', 's' => $sid));
 
     my $users = EBox::Global->modInstance('users');
     $users->groupExists($group)  or
@@ -416,8 +434,8 @@ sub _delGroupWarning
 
     my $path = BASEPATH . "/groups/$group";
     settextdomain('ebox-samba');
-    my $txt = __('This group has a sharing directory associated' .
-                               'which conatins data');
+    my $txt = __('This group has a sharing directory associated ' .
+                 'that contains data');
     settextdomain('ebox-usersandgroups');
 
     unless ($self->_directoryEmpty($path)) {
@@ -495,32 +513,6 @@ sub _createDir
     }
 }
 
-sub _setUserQuota
-{
-    my ($self, $uid, $quota)  = @_;
-
-    #FIXME
-    use constant INSOFT => 0;
-    use constant INHARD => 0;
-
-    $quota = $quota * 1024; #~Blocks
-    root("/usr/sbin/setquota -u $uid $quota $quota " . INSOFT . " " . INHARD . " -a");
-    root("/usr/sbin/setquota -t 0 0 -a");
-}
-
-sub _setAllUsersQuota
-{
-    my ($self) = @_;
-
-    my $users = EBox::Global->modInstance('users');
-    my $samba = EBox::Global->modInstance('samba');
-    my $quota = $samba->defaultUserQuota;
-
-    foreach my $user ($users->users) {
-        $self->_setUserQuota($user->{'uid'}, $quota);
-    }
-}
-
 sub _directoryEmpty
 {
     my ($self, $path) = @_;
@@ -714,9 +706,9 @@ sub groupShareDirectories
         my $group = $entry->get_value('cn');
         my $name  = $entry->get_value('displayResource');
         ($name) or next;
-        push (@share, { path      =>  BASEPATH . "/groups/$group",
-                groupname => $group,
-                sharename => $name
+        push (@share, { path      => BASEPATH . "/groups/$group",
+                        groupname => $group,
+                        sharename => $name
                   });
     }
     return \@share;
@@ -984,8 +976,10 @@ sub _fetchDomainAttrs
     return {} unless defined($entry);
     my %attributes;
     for my $attr (@attrs) {
-        $attributes{$attr} = $entry->get_value($attr);
-        return {} unless defined($attributes{$attr});
+       my $value = $entry->get_value($attr);
+       if (defined($value)) {
+               $attributes{$attr} = $value;
+       }
     }
     return \%attributes;
 }
@@ -1312,4 +1306,13 @@ sub acls
             "by * none" ];
 }
 
+# Method: defaultUserModel
+#
+#   Overrides <EBox::UsersAndGrops::LdapUserBase::defaultUserModel>
+#   to return our default user template
+sub defaultUserModel
+{
+    return 'samba/SambaUser';
+}
+
 1;
