@@ -3,4 +3,4 @@ CREATE TABLE samba_quarantine (
     qfilename VARCHAR(120),
     event VARCHAR(16),
     timestamp TIMESTAMP);
-CREATE INDEX samba_quarantine_i on samba_quarantine(timestamp);
+CREATE INDEX samba_quarantine_timestamp_i on samba_quarantine(timestamp);
